@@ -4,11 +4,11 @@
 -- icinga DB object definition for Oracle
 -- called and defines set from oracle.sql
 --
--- Copyright (c) 2009-2012 Icinga Development Team (http://www.icinga.org)
+-- Copyright (c) 2009-2013 Icinga Development Team (http://www.icinga.org)
 --
 -- initial version: 2008-02-20 David Schmidt
 --                  2011-01-17 Michael Friedrich <michael.friedrich(at)univie.ac.at>
--- current version: 2012-01-29 Thomas Dressler
+-- current version: 2012-10-31 Thomas Dressler
 -- -- --------------------------------------------------------
 */
 -- -----------------------------------------
@@ -708,10 +708,11 @@ CREATE TABLE eventhandlers (
   early_timeout integer default 0 ,
   execution_time number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob
 )
-lob (long_output) store as eventhandlers_out_lob(tablespace &&LOBTBS)
+lob (output) store as eventhandlers_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as eventhandlers_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table eventhandlers add constraint eventhandlers_pk PRIMARY KEY  (id)
@@ -844,10 +845,11 @@ CREATE TABLE hostchecks (
   execution_time number default 0 ,
   latency number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob)
-  lob (long_output) store as hostchecks_out_lob(tablespace &&LOBTBS)
+  lob (output) store as hostchecks_outp_lob(tablespace &&LOBTBS)
+  lob (long_output) store as hostchecks_loutp_lob(tablespace &&LOBTBS)
   lob (perfdata) store as hostchecks_perf_lob(tablespace &&LOBTBS)
   tablespace &&DATATBS;
 
@@ -1066,7 +1068,7 @@ CREATE TABLE hoststatus (
   instance_id integer default 0 ,
   host_object_id integer default 0 ,
   status_update_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob,
   current_state integer default 0 ,
@@ -1110,7 +1112,8 @@ CREATE TABLE hoststatus (
   retry_check_interval number default 0 ,
   check_timeperiod_object_id integer default 0 
 )
-lob (long_output) store as hoststatus_out_lob(tablespace &&LOBTBS)
+lob (output) store as hoststatus_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as hoststatus_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as hoststatus_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1178,12 +1181,13 @@ CREATE TABLE notifications (
   end_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   end_time_usec integer default 0 ,
   state integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   escalated integer default 0 ,
   contacts_notified integer default 0 
 )
-lob (long_output) store as notific_out_lob(tablespace &&LOBTBS)
+lob (output) store as notifications_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as notifications_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table notifications add constraint notifications_pk PRIMARY KEY  (id)
@@ -1256,6 +1260,7 @@ CREATE TABLE programstatus (
   last_command_check TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   last_log_rotation TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   notifications_enabled integer default 0 ,
+  disable_notif_expire_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
   active_service_checks_enabled integer default 0 ,
   passive_service_checks_enabled integer default 0 ,
   active_host_checks_enabled integer default 0 ,
@@ -1390,11 +1395,12 @@ CREATE TABLE servicechecks (
   execution_time number default 0 ,
   latency number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob
 )
-lob (long_output) store as servicechecks_out_lob(tablespace &&LOBTBS)
+lob (output) store as servicechecks_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as servicechecks_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as servicechecks_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1605,7 +1611,7 @@ CREATE TABLE servicestatus (
   instance_id integer default 0 ,
   service_object_id integer default 0 ,
   status_update_time TIMESTAMP(0) WITH LOCAL TIME ZONE default TO_TIMESTAMP_TZ('01.01.1970 UTC','DD.MM.YYYY TZR') ,
-  output varchar2(2048),
+  output clob,
   long_output clob,
   perfdata clob,
   current_state integer default 0 ,
@@ -1650,7 +1656,8 @@ CREATE TABLE servicestatus (
   retry_check_interval number default 0 ,
   check_timeperiod_object_id integer default 0 
 )
-lob (long_output) store as servicestatus_out_lob(tablespace &&LOBTBS)
+lob (output) store as servicestatus_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as servicestatus_loutp_lob(tablespace &&LOBTBS)
 lob (perfdata) store as servicestatus_perf_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
@@ -1679,10 +1686,11 @@ CREATE TABLE statehistory (
   max_check_attempts integer default 0 ,
   last_state integer default -1 ,
   last_hard_state integer default -1 ,
-  output varchar2(2048),
+  output clob,
   long_output clob
 )
-lob (long_output) store as statehistory_out_lob(tablespace &&LOBTBS)
+lob (output) store as statehistory_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as statehistory_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 alter table statehistory add constraint statehistory_pk PRIMARY KEY  (id)
 	using index tablespace &&IDXTBS;
@@ -1707,10 +1715,11 @@ CREATE TABLE systemcommands (
   early_timeout integer default 0 ,
   execution_time number default 0 ,
   return_code integer default 0 ,
-  output varchar2(2048),
+  output clob,
   long_output clob
 )
-lob (long_output) store as systemcommands_out_lob(tablespace &&LOBTBS)
+lob (output) store as systemcommands_outp_lob(tablespace &&LOBTBS)
+lob (long_output) store as systemcommands_loutp_lob(tablespace &&LOBTBS)
 tablespace &&DATATBS;
 
 alter table systemcommands add constraint systemcommands_pk PRIMARY KEY  (id)
@@ -1991,6 +2000,21 @@ CREATE INDEX contact_notif_meth_notif_idx ON contactnotificationmethods(contactn
 CREATE INDEX command_object_idx ON commands(object_id) tablespace &&IDXTBS;
 CREATE INDEX services_combined_object_idx ON services(service_object_id, host_object_id) tablespace &&IDXTBS;
 
+-- #2618
+CREATE INDEX cntgrpmbrs_cgid_coid ON contactgroup_members (contactgroup_id,contact_object_id) tablespace &&IDXTBS;
+CREATE INDEX hstgrpmbrs_hgid_hoid ON hostgroup_members (hostgroup_id,host_object_id) tablespace &&IDXTBS;
+CREATE INDEX hstcntgrps_hid_cgoid ON host_contactgroups (host_id,contactgroup_object_id) tablespace &&IDXTBS;
+CREATE INDEX hstprnthsts_hid_phoid ON host_parenthosts (host_id,parent_host_object_id) tablespace &&IDXTBS;
+CREATE INDEX runtimevars_iid_varn ON runtimevariables (instance_id,varname) tablespace &&IDXTBS;
+CREATE INDEX sgmbrs_sgid_soid ON servicegroup_members (servicegroup_id,service_object_id) tablespace &&IDXTBS;
+CREATE INDEX scgrps_sid_cgoid ON service_contactgroups (service_id,contactgroup_object_id) tablespace &&IDXTBS;
+CREATE INDEX tperiod_tid_d_ss_es ON timeperiod_timeranges (timeperiod_id,day,start_sec,end_sec) tablespace &&IDXTBS;
+
+-- #3649
+CREATE INDEX sla_idx_sthist ON statehistory (object_id, state_time DESC) tablespace &&IDXTBS;
+CREATE INDEX sla_idx_dohist ON downtimehistory (object_id, actual_start_time, actual_end_time) tablespace &&IDXTBS;
+CREATE INDEX sla_idx_obj ON objects (objecttype_id, is_active, name1) tablespace &&IDXTBS;
+
 -- -----------------------------------------
 -- sequences
 -- -----------------------------------------
