@@ -24,7 +24,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *****************************************************************************/
 
@@ -70,6 +70,7 @@ command         *ochp_command_ptr = NULL;
 
 char            *illegal_object_chars = NULL;
 char            *illegal_output_chars = NULL;
+char           illegal_output_char_map[] = CHAR_MAP_INIT(0);
 
 int             use_regexp_matches = FALSE;
 int             use_true_regexp_matching = FALSE;
@@ -272,6 +273,12 @@ int stalking_notifications_for_services = DEFAULT_STALKING_NOTIFICATIONS_FOR_SER
 
 time_t          last_program_stop = 0L;
 
+time_t disable_notifications_expire_time = 0L;
+void enable_all_notifications() {}
+
+int             keep_unknown_macros = FALSE;
+int		enable_state_based_escalation_ranges = FALSE;
+
 /* Dummy variables */
 sched_info scheduling_info;
 timed_event event_list_low;
@@ -288,6 +295,8 @@ int log_debug_info(int level, int verbosity, const char *fmt, ...) {
 	/* vprintf( fmt, ap ); */
 	va_end(ap);
 }
+int close_log_file(void) {}
+int chown_debug_log(uid_t uid, gid_t gid) {}
 
 int neb_free_callback_list(void) {}
 void broker_program_status(int type, int flags, int attr, struct timeval *timestamp) {}
@@ -318,6 +327,7 @@ int service_notification(service *svc, int type, char *not_author, char *not_dat
 
 /* Icinga special */
 int     event_profiling_enabled = FALSE;
+unsigned long max_check_result_list_items = DEFAULT_MAX_CHECK_RESULT_LIST_ITEMS;
 void    profiler_update(int event, struct timeval start) {}
 
 void remove_host_acknowledgement(host * hst) {}
